@@ -604,6 +604,16 @@ void *svt_aom_mode_decision_configuration_kernel(void *input_ptr) {
         if (pcs->slice_type != I_SLICE && !pcs->ppcs->sc_class1) {
             set_frame_coeff_lvl(pcs);
         }
+
+        // Whether or not to modulate the level of prediction tools using me-distortion
+        if (pcs->slice_type == I_SLICE) {
+            pcs->me_dist_mod = 0;
+        } else {
+            if (pcs->enc_mode <= ENC_M3)
+                pcs->me_dist_mod = 0;
+            else
+                pcs->me_dist_mod = 1;
+        }
         // -------
         // Scale references if resolution of the reference is different than the input
         // super-res reference frame size is same as original input size, only check current frame scaled flag;
